# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from tb_rest_client.models.models_pe.entity_filter import EntityFilter  # noqa: F401,E501

class EdgeTypeFilter(EntityFilter):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'edge_type': 'str',
        'edge_types': 'list[str]',
        'edge_name_filter': 'str'
    }
    if hasattr(EntityFilter, "swagger_types"):
        swagger_types.update(EntityFilter.swagger_types)

    attribute_map = {
        'edge_type': 'edgeType',
        'edge_types': 'edgeTypes',
        'edge_name_filter': 'edgeNameFilter'
    }
    if hasattr(EntityFilter, "attribute_map"):
        attribute_map.update(EntityFilter.attribute_map)

    def __init__(self, edge_type=None, edge_types=None, edge_name_filter=None, *args, **kwargs):  # noqa: E501
        """EdgeTypeFilter - a model defined in Swagger"""  # noqa: E501
        self._edge_type = None
        self._edge_types = None
        self._edge_name_filter = None
        self.discriminator = None
        if edge_type is not None:
            self.edge_type = edge_type
        if edge_types is not None:
            self.edge_types = edge_types
        if edge_name_filter is not None:
            self.edge_name_filter = edge_name_filter
        EntityFilter.__init__(self, *args, **kwargs)

    @property
    def edge_type(self):
        """Gets the edge_type of this EdgeTypeFilter.  # noqa: E501


        :return: The edge_type of this EdgeTypeFilter.  # noqa: E501
        :rtype: str
        """
        return self._edge_type

    @edge_type.setter
    def edge_type(self, edge_type):
        """Sets the edge_type of this EdgeTypeFilter.


        :param edge_type: The edge_type of this EdgeTypeFilter.  # noqa: E501
        :type: str
        """

        self._edge_type = edge_type

    @property
    def edge_types(self):
        """Gets the edge_types of this EdgeTypeFilter.  # noqa: E501


        :return: The edge_types of this EdgeTypeFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._edge_types

    @edge_types.setter
    def edge_types(self, edge_types):
        """Sets the edge_types of this EdgeTypeFilter.


        :param edge_types: The edge_types of this EdgeTypeFilter.  # noqa: E501
        :type: list[str]
        """

        self._edge_types = edge_types

    @property
    def edge_name_filter(self):
        """Gets the edge_name_filter of this EdgeTypeFilter.  # noqa: E501


        :return: The edge_name_filter of this EdgeTypeFilter.  # noqa: E501
        :rtype: str
        """
        return self._edge_name_filter

    @edge_name_filter.setter
    def edge_name_filter(self, edge_name_filter):
        """Sets the edge_name_filter of this EdgeTypeFilter.


        :param edge_name_filter: The edge_name_filter of this EdgeTypeFilter.  # noqa: E501
        :type: str
        """

        self._edge_name_filter = edge_name_filter

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EdgeTypeFilter, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EdgeTypeFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class EntityTypeVersionCreateConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'save_relations': 'bool',
        'save_attributes': 'bool',
        'save_credentials': 'bool',
        'save_permissions': 'bool',
        'save_group_entities': 'bool',
        'sync_strategy': 'str',
        'entity_ids': 'list[str]',
        'all_entities': 'bool'
    }

    attribute_map = {
        'save_relations': 'saveRelations',
        'save_attributes': 'saveAttributes',
        'save_credentials': 'saveCredentials',
        'save_permissions': 'savePermissions',
        'save_group_entities': 'saveGroupEntities',
        'sync_strategy': 'syncStrategy',
        'entity_ids': 'entityIds',
        'all_entities': 'allEntities'
    }

    def __init__(self, save_relations=None, save_attributes=None, save_credentials=None, save_permissions=None, save_group_entities=None, sync_strategy=None, entity_ids=None, all_entities=None):  # noqa: E501
        """EntityTypeVersionCreateConfig - a model defined in Swagger"""  # noqa: E501
        self._save_relations = None
        self._save_attributes = None
        self._save_credentials = None
        self._save_permissions = None
        self._save_group_entities = None
        self._sync_strategy = None
        self._entity_ids = None
        self._all_entities = None
        self.discriminator = None
        if save_relations is not None:
            self.save_relations = save_relations
        if save_attributes is not None:
            self.save_attributes = save_attributes
        if save_credentials is not None:
            self.save_credentials = save_credentials
        if save_permissions is not None:
            self.save_permissions = save_permissions
        if save_group_entities is not None:
            self.save_group_entities = save_group_entities
        if sync_strategy is not None:
            self.sync_strategy = sync_strategy
        if entity_ids is not None:
            self.entity_ids = entity_ids
        if all_entities is not None:
            self.all_entities = all_entities

    @property
    def save_relations(self):
        """Gets the save_relations of this EntityTypeVersionCreateConfig.  # noqa: E501


        :return: The save_relations of this EntityTypeVersionCreateConfig.  # noqa: E501
        :rtype: bool
        """
        return self._save_relations

    @save_relations.setter
    def save_relations(self, save_relations):
        """Sets the save_relations of this EntityTypeVersionCreateConfig.


        :param save_relations: The save_relations of this EntityTypeVersionCreateConfig.  # noqa: E501
        :type: bool
        """

        self._save_relations = save_relations

    @property
    def save_attributes(self):
        """Gets the save_attributes of this EntityTypeVersionCreateConfig.  # noqa: E501


        :return: The save_attributes of this EntityTypeVersionCreateConfig.  # noqa: E501
        :rtype: bool
        """
        return self._save_attributes

    @save_attributes.setter
    def save_attributes(self, save_attributes):
        """Sets the save_attributes of this EntityTypeVersionCreateConfig.


        :param save_attributes: The save_attributes of this EntityTypeVersionCreateConfig.  # noqa: E501
        :type: bool
        """

        self._save_attributes = save_attributes

    @property
    def save_credentials(self):
        """Gets the save_credentials of this EntityTypeVersionCreateConfig.  # noqa: E501


        :return: The save_credentials of this EntityTypeVersionCreateConfig.  # noqa: E501
        :rtype: bool
        """
        return self._save_credentials

    @save_credentials.setter
    def save_credentials(self, save_credentials):
        """Sets the save_credentials of this EntityTypeVersionCreateConfig.


        :param save_credentials: The save_credentials of this EntityTypeVersionCreateConfig.  # noqa: E501
        :type: bool
        """

        self._save_credentials = save_credentials

    @property
    def save_permissions(self):
        """Gets the save_permissions of this EntityTypeVersionCreateConfig.  # noqa: E501


        :return: The save_permissions of this EntityTypeVersionCreateConfig.  # noqa: E501
        :rtype: bool
        """
        return self._save_permissions

    @save_permissions.setter
    def save_permissions(self, save_permissions):
        """Sets the save_permissions of this EntityTypeVersionCreateConfig.


        :param save_permissions: The save_permissions of this EntityTypeVersionCreateConfig.  # noqa: E501
        :type: bool
        """

        self._save_permissions = save_permissions

    @property
    def save_group_entities(self):
        """Gets the save_group_entities of this EntityTypeVersionCreateConfig.  # noqa: E501


        :return: The save_group_entities of this EntityTypeVersionCreateConfig.  # noqa: E501
        :rtype: bool
        """
        return self._save_group_entities

    @save_group_entities.setter
    def save_group_entities(self, save_group_entities):
        """Sets the save_group_entities of this EntityTypeVersionCreateConfig.


        :param save_group_entities: The save_group_entities of this EntityTypeVersionCreateConfig.  # noqa: E501
        :type: bool
        """

        self._save_group_entities = save_group_entities

    @property
    def sync_strategy(self):
        """Gets the sync_strategy of this EntityTypeVersionCreateConfig.  # noqa: E501


        :return: The sync_strategy of this EntityTypeVersionCreateConfig.  # noqa: E501
        :rtype: str
        """
        return self._sync_strategy

    @sync_strategy.setter
    def sync_strategy(self, sync_strategy):
        """Sets the sync_strategy of this EntityTypeVersionCreateConfig.


        :param sync_strategy: The sync_strategy of this EntityTypeVersionCreateConfig.  # noqa: E501
        :type: str
        """
        allowed_values = ["MERGE", "OVERWRITE"]  # noqa: E501
        if sync_strategy not in allowed_values:
            raise ValueError(
                "Invalid value for `sync_strategy` ({0}), must be one of {1}"  # noqa: E501
                .format(sync_strategy, allowed_values)
            )

        self._sync_strategy = sync_strategy

    @property
    def entity_ids(self):
        """Gets the entity_ids of this EntityTypeVersionCreateConfig.  # noqa: E501


        :return: The entity_ids of this EntityTypeVersionCreateConfig.  # noqa: E501
        :rtype: list[str]
        """
        return self._entity_ids

    @entity_ids.setter
    def entity_ids(self, entity_ids):
        """Sets the entity_ids of this EntityTypeVersionCreateConfig.


        :param entity_ids: The entity_ids of this EntityTypeVersionCreateConfig.  # noqa: E501
        :type: list[str]
        """

        self._entity_ids = entity_ids

    @property
    def all_entities(self):
        """Gets the all_entities of this EntityTypeVersionCreateConfig.  # noqa: E501


        :return: The all_entities of this EntityTypeVersionCreateConfig.  # noqa: E501
        :rtype: bool
        """
        return self._all_entities

    @all_entities.setter
    def all_entities(self, all_entities):
        """Sets the all_entities of this EntityTypeVersionCreateConfig.


        :param all_entities: The all_entities of this EntityTypeVersionCreateConfig.  # noqa: E501
        :type: bool
        """

        self._all_entities = all_entities

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EntityTypeVersionCreateConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EntityTypeVersionCreateConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from tb_rest_client.models.models_pe.menu_item import MenuItem  # noqa: F401,E501

class HomeMenuItem(MenuItem):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'icon': 'str',
        'visible': 'bool',
        'pages': 'list[DefaultMenuItem]',
        'home_type': 'str',
        'dashboard_id': 'str',
        'hide_dashboard_toolbar': 'bool'
    }
    if hasattr(MenuItem, "swagger_types"):
        swagger_types.update(MenuItem.swagger_types)

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'icon': 'icon',
        'visible': 'visible',
        'pages': 'pages',
        'home_type': 'homeType',
        'dashboard_id': 'dashboardId',
        'hide_dashboard_toolbar': 'hideDashboardToolbar'
    }
    if hasattr(MenuItem, "attribute_map"):
        attribute_map.update(MenuItem.attribute_map)

    def __init__(self, id=None, name=None, icon=None, visible=None, pages=None, home_type=None, dashboard_id=None, hide_dashboard_toolbar=None, *args, **kwargs):  # noqa: E501
        """HomeMenuItem - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._icon = None
        self._visible = None
        self._pages = None
        self._home_type = None
        self._dashboard_id = None
        self._hide_dashboard_toolbar = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if icon is not None:
            self.icon = icon
        if visible is not None:
            self.visible = visible
        if pages is not None:
            self.pages = pages
        if home_type is not None:
            self.home_type = home_type
        if dashboard_id is not None:
            self.dashboard_id = dashboard_id
        if hide_dashboard_toolbar is not None:
            self.hide_dashboard_toolbar = hide_dashboard_toolbar
        MenuItem.__init__(self, *args, **kwargs)

    @property
    def id(self):
        """Gets the id of this HomeMenuItem.  # noqa: E501

        Unique identifier for predefined menu items  # noqa: E501

        :return: The id of this HomeMenuItem.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this HomeMenuItem.

        Unique identifier for predefined menu items  # noqa: E501

        :param id: The id of this HomeMenuItem.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this HomeMenuItem.  # noqa: E501

        Name of the menu item  # noqa: E501

        :return: The name of this HomeMenuItem.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this HomeMenuItem.

        Name of the menu item  # noqa: E501

        :param name: The name of this HomeMenuItem.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def icon(self):
        """Gets the icon of this HomeMenuItem.  # noqa: E501

        URL of the menu item icon. Overrides 'materialIcon'  # noqa: E501

        :return: The icon of this HomeMenuItem.  # noqa: E501
        :rtype: str
        """
        return self._icon

    @icon.setter
    def icon(self, icon):
        """Sets the icon of this HomeMenuItem.

        URL of the menu item icon. Overrides 'materialIcon'  # noqa: E501

        :param icon: The icon of this HomeMenuItem.  # noqa: E501
        :type: str
        """

        self._icon = icon

    @property
    def visible(self):
        """Gets the visible of this HomeMenuItem.  # noqa: E501

        Mark if menu item is visible for user  # noqa: E501

        :return: The visible of this HomeMenuItem.  # noqa: E501
        :rtype: bool
        """
        return self._visible

    @visible.setter
    def visible(self, visible):
        """Sets the visible of this HomeMenuItem.

        Mark if menu item is visible for user  # noqa: E501

        :param visible: The visible of this HomeMenuItem.  # noqa: E501
        :type: bool
        """

        self._visible = visible

    @property
    def pages(self):
        """Gets the pages of this HomeMenuItem.  # noqa: E501

        List of child menu items  # noqa: E501

        :return: The pages of this HomeMenuItem.  # noqa: E501
        :rtype: list[DefaultMenuItem]
        """
        return self._pages

    @pages.setter
    def pages(self, pages):
        """Sets the pages of this HomeMenuItem.

        List of child menu items  # noqa: E501

        :param pages: The pages of this HomeMenuItem.  # noqa: E501
        :type: list[DefaultMenuItem]
        """

        self._pages = pages

    @property
    def home_type(self):
        """Gets the home_type of this HomeMenuItem.  # noqa: E501

        DEFAULT or DASHBOARD. DASHBOARD means default home page presentation changed to refer to dashboard  # noqa: E501

        :return: The home_type of this HomeMenuItem.  # noqa: E501
        :rtype: str
        """
        return self._home_type

    @home_type.setter
    def home_type(self, home_type):
        """Sets the home_type of this HomeMenuItem.

        DEFAULT or DASHBOARD. DASHBOARD means default home page presentation changed to refer to dashboard  # noqa: E501

        :param home_type: The home_type of this HomeMenuItem.  # noqa: E501
        :type: str
        """
        allowed_values = ["DEFAULT", "DASHBOARD"]  # noqa: E501
        if home_type not in allowed_values:
            raise ValueError(
                "Invalid value for `home_type` ({0}), must be one of {1}"  # noqa: E501
                .format(home_type, allowed_values)
            )

        self._home_type = home_type

    @property
    def dashboard_id(self):
        """Gets the dashboard_id of this HomeMenuItem.  # noqa: E501

        Id of the Dashboard to open, when user clicks the menu item  # noqa: E501

        :return: The dashboard_id of this HomeMenuItem.  # noqa: E501
        :rtype: str
        """
        return self._dashboard_id

    @dashboard_id.setter
    def dashboard_id(self, dashboard_id):
        """Sets the dashboard_id of this HomeMenuItem.

        Id of the Dashboard to open, when user clicks the menu item  # noqa: E501

        :param dashboard_id: The dashboard_id of this HomeMenuItem.  # noqa: E501
        :type: str
        """

        self._dashboard_id = dashboard_id

    @property
    def hide_dashboard_toolbar(self):
        """Gets the hide_dashboard_toolbar of this HomeMenuItem.  # noqa: E501

        Hide the dashboard toolbar  # noqa: E501

        :return: The hide_dashboard_toolbar of this HomeMenuItem.  # noqa: E501
        :rtype: bool
        """
        return self._hide_dashboard_toolbar

    @hide_dashboard_toolbar.setter
    def hide_dashboard_toolbar(self, hide_dashboard_toolbar):
        """Sets the hide_dashboard_toolbar of this HomeMenuItem.

        Hide the dashboard toolbar  # noqa: E501

        :param hide_dashboard_toolbar: The hide_dashboard_toolbar of this HomeMenuItem.  # noqa: E501
        :type: bool
        """

        self._hide_dashboard_toolbar = hide_dashboard_toolbar

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HomeMenuItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HomeMenuItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class EntityGroupInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'EntityGroupId',
        'created_time': 'int',
        'type': 'str',
        'name': 'str',
        'owner_id': 'EntityId',
        'additional_info': 'JsonNode',
        'configuration': 'JsonNode',
        'version': 'int',
        'owner_ids': 'list[EntityId]',
        'edge_group_all': 'bool',
        'group_all': 'bool',
        'tenant_id': 'TenantId'
    }

    attribute_map = {
        'id': 'id',
        'created_time': 'createdTime',
        'type': 'type',
        'name': 'name',
        'owner_id': 'ownerId',
        'additional_info': 'additionalInfo',
        'configuration': 'configuration',
        'version': 'version',
        'owner_ids': 'ownerIds',
        'edge_group_all': 'edgeGroupAll',
        'group_all': 'groupAll',
        'tenant_id': 'tenantId'
    }

    def __init__(self, id=None, created_time=None, type=None, name=None, owner_id=None, additional_info=None, configuration=None, version=None, owner_ids=None, edge_group_all=None, group_all=None, tenant_id=None):  # noqa: E501
        """EntityGroupInfo - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._created_time = None
        self._type = None
        self._name = None
        self._owner_id = None
        self._additional_info = None
        self._configuration = None
        self._version = None
        self._owner_ids = None
        self._edge_group_all = None
        self._group_all = None
        self._tenant_id = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if created_time is not None:
            self.created_time = created_time
        self.type = type
        self.name = name
        if owner_id is not None:
            self.owner_id = owner_id
        if additional_info is not None:
            self.additional_info = additional_info
        if configuration is not None:
            self.configuration = configuration
        if version is not None:
            self.version = version
        self.owner_ids = owner_ids
        if edge_group_all is not None:
            self.edge_group_all = edge_group_all
        if group_all is not None:
            self.group_all = group_all
        if tenant_id is not None:
            self.tenant_id = tenant_id

    @property
    def id(self):
        """Gets the id of this EntityGroupInfo.  # noqa: E501


        :return: The id of this EntityGroupInfo.  # noqa: E501
        :rtype: EntityGroupId
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this EntityGroupInfo.


        :param id: The id of this EntityGroupInfo.  # noqa: E501
        :type: EntityGroupId
        """

        self._id = id

    @property
    def created_time(self):
        """Gets the created_time of this EntityGroupInfo.  # noqa: E501

        Timestamp of the entity group creation, in milliseconds  # noqa: E501

        :return: The created_time of this EntityGroupInfo.  # noqa: E501
        :rtype: int
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this EntityGroupInfo.

        Timestamp of the entity group creation, in milliseconds  # noqa: E501

        :param created_time: The created_time of this EntityGroupInfo.  # noqa: E501
        :type: int
        """

        self._created_time = created_time

    @property
    def type(self):
        """Gets the type of this EntityGroupInfo.  # noqa: E501


        :return: The type of this EntityGroupInfo.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this EntityGroupInfo.


        :param type: The type of this EntityGroupInfo.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["CUSTOMER", "ASSET", "DEVICE", "USER", "ENTITY_VIEW", "DASHBOARD", "EDGE"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def name(self):
        """Gets the name of this EntityGroupInfo.  # noqa: E501

        Name of the entity group  # noqa: E501

        :return: The name of this EntityGroupInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this EntityGroupInfo.

        Name of the entity group  # noqa: E501

        :param name: The name of this EntityGroupInfo.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def owner_id(self):
        """Gets the owner_id of this EntityGroupInfo.  # noqa: E501


        :return: The owner_id of this EntityGroupInfo.  # noqa: E501
        :rtype: EntityId
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this EntityGroupInfo.


        :param owner_id: The owner_id of this EntityGroupInfo.  # noqa: E501
        :type: EntityId
        """

        self._owner_id = owner_id

    @property
    def additional_info(self):
        """Gets the additional_info of this EntityGroupInfo.  # noqa: E501


        :return: The additional_info of this EntityGroupInfo.  # noqa: E501
        :rtype: JsonNode
        """
        return self._additional_info

    @additional_info.setter
    def additional_info(self, additional_info):
        """Sets the additional_info of this EntityGroupInfo.


        :param additional_info: The additional_info of this EntityGroupInfo.  # noqa: E501
        :type: JsonNode
        """

        self._additional_info = additional_info

    @property
    def configuration(self):
        """Gets the configuration of this EntityGroupInfo.  # noqa: E501


        :return: The configuration of this EntityGroupInfo.  # noqa: E501
        :rtype: JsonNode
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this EntityGroupInfo.


        :param configuration: The configuration of this EntityGroupInfo.  # noqa: E501
        :type: JsonNode
        """

        self._configuration = configuration

    @property
    def version(self):
        """Gets the version of this EntityGroupInfo.  # noqa: E501


        :return: The version of this EntityGroupInfo.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this EntityGroupInfo.


        :param version: The version of this EntityGroupInfo.  # noqa: E501
        :type: int
        """

        self._version = version

    @property
    def owner_ids(self):
        """Gets the owner_ids of this EntityGroupInfo.  # noqa: E501

        List of the entity group owners.  # noqa: E501

        :return: The owner_ids of this EntityGroupInfo.  # noqa: E501
        :rtype: list[EntityId]
        """
        return self._owner_ids

    @owner_ids.setter
    def owner_ids(self, owner_ids):
        """Sets the owner_ids of this EntityGroupInfo.

        List of the entity group owners.  # noqa: E501

        :param owner_ids: The owner_ids of this EntityGroupInfo.  # noqa: E501
        :type: list[EntityId]
        """
        if owner_ids is None:
            raise ValueError("Invalid value for `owner_ids`, must not be `None`")  # noqa: E501

        self._owner_ids = owner_ids

    @property
    def edge_group_all(self):
        """Gets the edge_group_all of this EntityGroupInfo.  # noqa: E501

        Indicates special edge group 'All' that contains all entities and can't be deleted.  # noqa: E501

        :return: The edge_group_all of this EntityGroupInfo.  # noqa: E501
        :rtype: bool
        """
        return self._edge_group_all

    @edge_group_all.setter
    def edge_group_all(self, edge_group_all):
        """Sets the edge_group_all of this EntityGroupInfo.

        Indicates special edge group 'All' that contains all entities and can't be deleted.  # noqa: E501

        :param edge_group_all: The edge_group_all of this EntityGroupInfo.  # noqa: E501
        :type: bool
        """

        self._edge_group_all = edge_group_all

    @property
    def group_all(self):
        """Gets the group_all of this EntityGroupInfo.  # noqa: E501

        Indicates special group 'All' that contains all entities and can't be deleted.  # noqa: E501

        :return: The group_all of this EntityGroupInfo.  # noqa: E501
        :rtype: bool
        """
        return self._group_all

    @group_all.setter
    def group_all(self, group_all):
        """Sets the group_all of this EntityGroupInfo.

        Indicates special group 'All' that contains all entities and can't be deleted.  # noqa: E501

        :param group_all: The group_all of this EntityGroupInfo.  # noqa: E501
        :type: bool
        """

        self._group_all = group_all

    @property
    def tenant_id(self):
        """Gets the tenant_id of this EntityGroupInfo.  # noqa: E501


        :return: The tenant_id of this EntityGroupInfo.  # noqa: E501
        :rtype: TenantId
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this EntityGroupInfo.


        :param tenant_id: The tenant_id of this EntityGroupInfo.  # noqa: E501
        :type: TenantId
        """

        self._tenant_id = tenant_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EntityGroupInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EntityGroupInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class AssetSearchQuery(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'parameters': 'RelationsSearchParameters',
        'relation_type': 'str',
        'asset_types': 'list[str]'
    }

    attribute_map = {
        'parameters': 'parameters',
        'relation_type': 'relationType',
        'asset_types': 'assetTypes'
    }

    def __init__(self, parameters=None, relation_type=None, asset_types=None):  # noqa: E501
        """AssetSearchQuery - a model defined in Swagger"""  # noqa: E501
        self._parameters = None
        self._relation_type = None
        self._asset_types = None
        self.discriminator = None
        if parameters is not None:
            self.parameters = parameters
        if relation_type is not None:
            self.relation_type = relation_type
        if asset_types is not None:
            self.asset_types = asset_types

    @property
    def parameters(self):
        """Gets the parameters of this AssetSearchQuery.  # noqa: E501


        :return: The parameters of this AssetSearchQuery.  # noqa: E501
        :rtype: RelationsSearchParameters
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this AssetSearchQuery.


        :param parameters: The parameters of this AssetSearchQuery.  # noqa: E501
        :type: RelationsSearchParameters
        """

        self._parameters = parameters

    @property
    def relation_type(self):
        """Gets the relation_type of this AssetSearchQuery.  # noqa: E501

        Type of the relation between root entity and asset (e.g. 'Contains' or 'Manages').  # noqa: E501

        :return: The relation_type of this AssetSearchQuery.  # noqa: E501
        :rtype: str
        """
        return self._relation_type

    @relation_type.setter
    def relation_type(self, relation_type):
        """Sets the relation_type of this AssetSearchQuery.

        Type of the relation between root entity and asset (e.g. 'Contains' or 'Manages').  # noqa: E501

        :param relation_type: The relation_type of this AssetSearchQuery.  # noqa: E501
        :type: str
        """

        self._relation_type = relation_type

    @property
    def asset_types(self):
        """Gets the asset_types of this AssetSearchQuery.  # noqa: E501

        Array of asset types to filter the related entities (e.g. 'Building', 'Vehicle').  # noqa: E501

        :return: The asset_types of this AssetSearchQuery.  # noqa: E501
        :rtype: list[str]
        """
        return self._asset_types

    @asset_types.setter
    def asset_types(self, asset_types):
        """Sets the asset_types of this AssetSearchQuery.

        Array of asset types to filter the related entities (e.g. 'Building', 'Vehicle').  # noqa: E501

        :param asset_types: The asset_types of this AssetSearchQuery.  # noqa: E501
        :type: list[str]
        """

        self._asset_types = asset_types

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AssetSearchQuery, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssetSearchQuery):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

    For instructions how to authorize requests please visit <a href='http://thingsboard.io/docs/reference/rest-api/'>REST API documentation page</a>.  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from tb_rest_client.api_client import ApiClient


class TMobileIotCdpIntegrationControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def process_request_using_delete4(self, body, request_headers, routing_key, **kwargs):  # noqa: E501
        """processRequest  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_request_using_delete4(body, request_headers, routing_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: msg (required)
        :param Object request_headers: requestHeaders (required)
        :param str routing_key: routingKey (required)
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.process_request_using_delete4_with_http_info(body, request_headers, routing_key, **kwargs)  # noqa: E501
        else:
            (data) = self.process_request_using_delete4_with_http_info(body, request_headers, routing_key, **kwargs)  # noqa: E501
            return data

    def process_request_using_delete4_with_http_info(self, body, request_headers, routing_key, **kwargs):  # noqa: E501
        """processRequest  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_request_using_delete4_with_http_info(body, request_headers, routing_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: msg (required)
        :param Object request_headers: requestHeaders (required)
        :param str routing_key: routingKey (required)
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'request_headers', 'routing_key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method process_request_using_delete4" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `process_request_using_delete4`")  # noqa: E501
        # verify the required parameter 'request_headers' is set
        if ('request_headers' not in params or
                params['request_headers'] is None):
            raise ValueError("Missing the required parameter `request_headers` when calling `process_request_using_delete4`")  # noqa: E501
        # verify the required parameter 'routing_key' is set
        if ('routing_key' not in params or
                params['routing_key'] is None):
            raise ValueError("Missing the required parameter `routing_key` when calling `process_request_using_delete4`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'routing_key' in params:
            path_params['routingKey'] = params['routing_key']  # noqa: E501

        query_params = []

        header_params = {}
        if 'request_headers' in params:
            header_params['requestHeaders'] = params['request_headers']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/integrations/tmobile_iot_cdp/{routingKey}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeferredResultResponseEntity',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def process_request_using_get4(self, body, request_headers, routing_key, **kwargs):  # noqa: E501
        """processRequest  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_request_using_get4(body, request_headers, routing_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: msg (required)
        :param Object request_headers: requestHeaders (required)
        :param str routing_key: routingKey (required)
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.process_request_using_get4_with_http_info(body, request_headers, routing_key, **kwargs)  # noqa: E501
        else:
            (data) = self.process_request_using_get4_with_http_info(body, request_headers, routing_key, **kwargs)  # noqa: E501
            return data

    def process_request_using_get4_with_http_info(self, body, request_headers, routing_key, **kwargs):  # noqa: E501
        """processRequest  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_request_using_get4_with_http_info(body, request_headers, routing_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: msg (required)
        :param Object request_headers: requestHeaders (required)
        :param str routing_key: routingKey (required)
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'request_headers', 'routing_key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method process_request_using_get4" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `process_request_using_get4`")  # noqa: E501
        # verify the required parameter 'request_headers' is set
        if ('request_headers' not in params or
                params['request_headers'] is None):
            raise ValueError("Missing the required parameter `request_headers` when calling `process_request_using_get4`")  # noqa: E501
        # verify the required parameter 'routing_key' is set
        if ('routing_key' not in params or
                params['routing_key'] is None):
            raise ValueError("Missing the required parameter `routing_key` when calling `process_request_using_get4`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'routing_key' in params:
            path_params['routingKey'] = params['routing_key']  # noqa: E501

        query_params = []

        header_params = {}
        if 'request_headers' in params:
            header_params['requestHeaders'] = params['request_headers']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/integrations/tmobile_iot_cdp/{routingKey}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeferredResultResponseEntity',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def process_request_using_head4(self, body, request_headers, routing_key, **kwargs):  # noqa: E501
        """processRequest  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_request_using_head4(body, request_headers, routing_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: msg (required)
        :param Object request_headers: requestHeaders (required)
        :param str routing_key: routingKey (required)
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.process_request_using_head4_with_http_info(body, request_headers, routing_key, **kwargs)  # noqa: E501
        else:
            (data) = self.process_request_using_head4_with_http_info(body, request_headers, routing_key, **kwargs)  # noqa: E501
            return data

    def process_request_using_head4_with_http_info(self, body, request_headers, routing_key, **kwargs):  # noqa: E501
        """processRequest  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_request_using_head4_with_http_info(body, request_headers, routing_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: msg (required)
        :param Object request_headers: requestHeaders (required)
        :param str routing_key: routingKey (required)
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'request_headers', 'routing_key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method process_request_using_head4" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `process_request_using_head4`")  # noqa: E501
        # verify the required parameter 'request_headers' is set
        if ('request_headers' not in params or
                params['request_headers'] is None):
            raise ValueError("Missing the required parameter `request_headers` when calling `process_request_using_head4`")  # noqa: E501
        # verify the required parameter 'routing_key' is set
        if ('routing_key' not in params or
                params['routing_key'] is None):
            raise ValueError("Missing the required parameter `routing_key` when calling `process_request_using_head4`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'routing_key' in params:
            path_params['routingKey'] = params['routing_key']  # noqa: E501

        query_params = []

        header_params = {}
        if 'request_headers' in params:
            header_params['requestHeaders'] = params['request_headers']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/integrations/tmobile_iot_cdp/{routingKey}', 'HEAD',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeferredResultResponseEntity',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def process_request_using_options4(self, body, request_headers, routing_key, **kwargs):  # noqa: E501
        """processRequest  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_request_using_options4(body, request_headers, routing_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: msg (required)
        :param Object request_headers: requestHeaders (required)
        :param str routing_key: routingKey (required)
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.process_request_using_options4_with_http_info(body, request_headers, routing_key, **kwargs)  # noqa: E501
        else:
            (data) = self.process_request_using_options4_with_http_info(body, request_headers, routing_key, **kwargs)  # noqa: E501
            return data

    def process_request_using_options4_with_http_info(self, body, request_headers, routing_key, **kwargs):  # noqa: E501
        """processRequest  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_request_using_options4_with_http_info(body, request_headers, routing_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: msg (required)
        :param Object request_headers: requestHeaders (required)
        :param str routing_key: routingKey (required)
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'request_headers', 'routing_key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method process_request_using_options4" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `process_request_using_options4`")  # noqa: E501
        # verify the required parameter 'request_headers' is set
        if ('request_headers' not in params or
                params['request_headers'] is None):
            raise ValueError("Missing the required parameter `request_headers` when calling `process_request_using_options4`")  # noqa: E501
        # verify the required parameter 'routing_key' is set
        if ('routing_key' not in params or
                params['routing_key'] is None):
            raise ValueError("Missing the required parameter `routing_key` when calling `process_request_using_options4`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'routing_key' in params:
            path_params['routingKey'] = params['routing_key']  # noqa: E501

        query_params = []

        header_params = {}
        if 'request_headers' in params:
            header_params['requestHeaders'] = params['request_headers']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/integrations/tmobile_iot_cdp/{routingKey}', 'OPTIONS',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeferredResultResponseEntity',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def process_request_using_patch4(self, body, request_headers, routing_key, **kwargs):  # noqa: E501
        """processRequest  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_request_using_patch4(body, request_headers, routing_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: msg (required)
        :param Object request_headers: requestHeaders (required)
        :param str routing_key: routingKey (required)
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.process_request_using_patch4_with_http_info(body, request_headers, routing_key, **kwargs)  # noqa: E501
        else:
            (data) = self.process_request_using_patch4_with_http_info(body, request_headers, routing_key, **kwargs)  # noqa: E501
            return data

    def process_request_using_patch4_with_http_info(self, body, request_headers, routing_key, **kwargs):  # noqa: E501
        """processRequest  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_request_using_patch4_with_http_info(body, request_headers, routing_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: msg (required)
        :param Object request_headers: requestHeaders (required)
        :param str routing_key: routingKey (required)
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'request_headers', 'routing_key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method process_request_using_patch4" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `process_request_using_patch4`")  # noqa: E501
        # verify the required parameter 'request_headers' is set
        if ('request_headers' not in params or
                params['request_headers'] is None):
            raise ValueError("Missing the required parameter `request_headers` when calling `process_request_using_patch4`")  # noqa: E501
        # verify the required parameter 'routing_key' is set
        if ('routing_key' not in params or
                params['routing_key'] is None):
            raise ValueError("Missing the required parameter `routing_key` when calling `process_request_using_patch4`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'routing_key' in params:
            path_params['routingKey'] = params['routing_key']  # noqa: E501

        query_params = []

        header_params = {}
        if 'request_headers' in params:
            header_params['requestHeaders'] = params['request_headers']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/integrations/tmobile_iot_cdp/{routingKey}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeferredResultResponseEntity',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def process_request_using_post12(self, body, request_headers, routing_key, **kwargs):  # noqa: E501
        """processRequest  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_request_using_post12(body, request_headers, routing_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: msg (required)
        :param Object request_headers: requestHeaders (required)
        :param str routing_key: routingKey (required)
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.process_request_using_post12_with_http_info(body, request_headers, routing_key, **kwargs)  # noqa: E501
        else:
            (data) = self.process_request_using_post12_with_http_info(body, request_headers, routing_key, **kwargs)  # noqa: E501
            return data

    def process_request_using_post12_with_http_info(self, body, request_headers, routing_key, **kwargs):  # noqa: E501
        """processRequest  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_request_using_post12_with_http_info(body, request_headers, routing_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: msg (required)
        :param Object request_headers: requestHeaders (required)
        :param str routing_key: routingKey (required)
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'request_headers', 'routing_key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method process_request_using_post12" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `process_request_using_post12`")  # noqa: E501
        # verify the required parameter 'request_headers' is set
        if ('request_headers' not in params or
                params['request_headers'] is None):
            raise ValueError("Missing the required parameter `request_headers` when calling `process_request_using_post12`")  # noqa: E501
        # verify the required parameter 'routing_key' is set
        if ('routing_key' not in params or
                params['routing_key'] is None):
            raise ValueError("Missing the required parameter `routing_key` when calling `process_request_using_post12`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'routing_key' in params:
            path_params['routingKey'] = params['routing_key']  # noqa: E501

        query_params = []

        header_params = {}
        if 'request_headers' in params:
            header_params['requestHeaders'] = params['request_headers']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/integrations/tmobile_iot_cdp/{routingKey}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeferredResultResponseEntity',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def process_request_using_put4(self, body, request_headers, routing_key, **kwargs):  # noqa: E501
        """processRequest  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_request_using_put4(body, request_headers, routing_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: msg (required)
        :param Object request_headers: requestHeaders (required)
        :param str routing_key: routingKey (required)
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.process_request_using_put4_with_http_info(body, request_headers, routing_key, **kwargs)  # noqa: E501
        else:
            (data) = self.process_request_using_put4_with_http_info(body, request_headers, routing_key, **kwargs)  # noqa: E501
            return data

    def process_request_using_put4_with_http_info(self, body, request_headers, routing_key, **kwargs):  # noqa: E501
        """processRequest  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_request_using_put4_with_http_info(body, request_headers, routing_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: msg (required)
        :param Object request_headers: requestHeaders (required)
        :param str routing_key: routingKey (required)
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'request_headers', 'routing_key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method process_request_using_put4" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `process_request_using_put4`")  # noqa: E501
        # verify the required parameter 'request_headers' is set
        if ('request_headers' not in params or
                params['request_headers'] is None):
            raise ValueError("Missing the required parameter `request_headers` when calling `process_request_using_put4`")  # noqa: E501
        # verify the required parameter 'routing_key' is set
        if ('routing_key' not in params or
                params['routing_key'] is None):
            raise ValueError("Missing the required parameter `routing_key` when calling `process_request_using_put4`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'routing_key' in params:
            path_params['routingKey'] = params['routing_key']  # noqa: E501

        query_params = []

        header_params = {}
        if 'request_headers' in params:
            header_params['requestHeaders'] = params['request_headers']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/integrations/tmobile_iot_cdp/{routingKey}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeferredResultResponseEntity',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class SecuritySettings(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'password_policy': 'UserPasswordPolicy',
        'max_failed_login_attempts': 'int',
        'user_lockout_notification_email': 'str',
        'mobile_secret_key_length': 'int',
        'user_activation_token_ttl': 'int',
        'password_reset_token_ttl': 'int'
    }

    attribute_map = {
        'password_policy': 'passwordPolicy',
        'max_failed_login_attempts': 'maxFailedLoginAttempts',
        'user_lockout_notification_email': 'userLockoutNotificationEmail',
        'mobile_secret_key_length': 'mobileSecretKeyLength',
        'user_activation_token_ttl': 'userActivationTokenTtl',
        'password_reset_token_ttl': 'passwordResetTokenTtl'
    }

    def __init__(self, password_policy=None, max_failed_login_attempts=None, user_lockout_notification_email=None, mobile_secret_key_length=None, user_activation_token_ttl=None, password_reset_token_ttl=None):  # noqa: E501
        """SecuritySettings - a model defined in Swagger"""  # noqa: E501
        self._password_policy = None
        self._max_failed_login_attempts = None
        self._user_lockout_notification_email = None
        self._mobile_secret_key_length = None
        self._user_activation_token_ttl = None
        self._password_reset_token_ttl = None
        self.discriminator = None
        if password_policy is not None:
            self.password_policy = password_policy
        if max_failed_login_attempts is not None:
            self.max_failed_login_attempts = max_failed_login_attempts
        if user_lockout_notification_email is not None:
            self.user_lockout_notification_email = user_lockout_notification_email
        if mobile_secret_key_length is not None:
            self.mobile_secret_key_length = mobile_secret_key_length
        self.user_activation_token_ttl = user_activation_token_ttl
        self.password_reset_token_ttl = password_reset_token_ttl

    @property
    def password_policy(self):
        """Gets the password_policy of this SecuritySettings.  # noqa: E501


        :return: The password_policy of this SecuritySettings.  # noqa: E501
        :rtype: UserPasswordPolicy
        """
        return self._password_policy

    @password_policy.setter
    def password_policy(self, password_policy):
        """Sets the password_policy of this SecuritySettings.


        :param password_policy: The password_policy of this SecuritySettings.  # noqa: E501
        :type: UserPasswordPolicy
        """

        self._password_policy = password_policy

    @property
    def max_failed_login_attempts(self):
        """Gets the max_failed_login_attempts of this SecuritySettings.  # noqa: E501

        Maximum number of failed login attempts allowed before user account is locked.  # noqa: E501

        :return: The max_failed_login_attempts of this SecuritySettings.  # noqa: E501
        :rtype: int
        """
        return self._max_failed_login_attempts

    @max_failed_login_attempts.setter
    def max_failed_login_attempts(self, max_failed_login_attempts):
        """Sets the max_failed_login_attempts of this SecuritySettings.

        Maximum number of failed login attempts allowed before user account is locked.  # noqa: E501

        :param max_failed_login_attempts: The max_failed_login_attempts of this SecuritySettings.  # noqa: E501
        :type: int
        """

        self._max_failed_login_attempts = max_failed_login_attempts

    @property
    def user_lockout_notification_email(self):
        """Gets the user_lockout_notification_email of this SecuritySettings.  # noqa: E501

        Email to use for notifications about locked users.  # noqa: E501

        :return: The user_lockout_notification_email of this SecuritySettings.  # noqa: E501
        :rtype: str
        """
        return self._user_lockout_notification_email

    @user_lockout_notification_email.setter
    def user_lockout_notification_email(self, user_lockout_notification_email):
        """Sets the user_lockout_notification_email of this SecuritySettings.

        Email to use for notifications about locked users.  # noqa: E501

        :param user_lockout_notification_email: The user_lockout_notification_email of this SecuritySettings.  # noqa: E501
        :type: str
        """

        self._user_lockout_notification_email = user_lockout_notification_email

    @property
    def mobile_secret_key_length(self):
        """Gets the mobile_secret_key_length of this SecuritySettings.  # noqa: E501

        Mobile secret key length  # noqa: E501

        :return: The mobile_secret_key_length of this SecuritySettings.  # noqa: E501
        :rtype: int
        """
        return self._mobile_secret_key_length

    @mobile_secret_key_length.setter
    def mobile_secret_key_length(self, mobile_secret_key_length):
        """Sets the mobile_secret_key_length of this SecuritySettings.

        Mobile secret key length  # noqa: E501

        :param mobile_secret_key_length: The mobile_secret_key_length of this SecuritySettings.  # noqa: E501
        :type: int
        """

        self._mobile_secret_key_length = mobile_secret_key_length

    @property
    def user_activation_token_ttl(self):
        """Gets the user_activation_token_ttl of this SecuritySettings.  # noqa: E501

        TTL in hours for user activation link  # noqa: E501

        :return: The user_activation_token_ttl of this SecuritySettings.  # noqa: E501
        :rtype: int
        """
        return self._user_activation_token_ttl

    @user_activation_token_ttl.setter
    def user_activation_token_ttl(self, user_activation_token_ttl):
        """Sets the user_activation_token_ttl of this SecuritySettings.

        TTL in hours for user activation link  # noqa: E501

        :param user_activation_token_ttl: The user_activation_token_ttl of this SecuritySettings.  # noqa: E501
        :type: int
        """
        if user_activation_token_ttl is None:
            raise ValueError("Invalid value for `user_activation_token_ttl`, must not be `None`")  # noqa: E501

        self._user_activation_token_ttl = user_activation_token_ttl

    @property
    def password_reset_token_ttl(self):
        """Gets the password_reset_token_ttl of this SecuritySettings.  # noqa: E501

        TTL in hours for password reset link  # noqa: E501

        :return: The password_reset_token_ttl of this SecuritySettings.  # noqa: E501
        :rtype: int
        """
        return self._password_reset_token_ttl

    @password_reset_token_ttl.setter
    def password_reset_token_ttl(self, password_reset_token_ttl):
        """Sets the password_reset_token_ttl of this SecuritySettings.

        TTL in hours for password reset link  # noqa: E501

        :param password_reset_token_ttl: The password_reset_token_ttl of this SecuritySettings.  # noqa: E501
        :type: int
        """
        if password_reset_token_ttl is None:
            raise ValueError("Invalid value for `password_reset_token_ttl`, must not be `None`")  # noqa: E501

        self._password_reset_token_ttl = password_reset_token_ttl

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SecuritySettings, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SecuritySettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six
from tb_rest_client.models.models_ce.notification_target_config import NotificationTargetConfig  # noqa: F401,E501

class MicrosoftTeamsNotificationTargetConfig(NotificationTargetConfig):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'webhook_url': 'str',
        'channel_name': 'str',
        'use_old_api': 'bool',
        'title': 'str',
        'id': 'object',
        'email': 'str',
        'first_name': 'str',
        'last_name': 'str'
    }
    if hasattr(NotificationTargetConfig, "swagger_types"):
        swagger_types.update(NotificationTargetConfig.swagger_types)

    attribute_map = {
        'webhook_url': 'webhookUrl',
        'channel_name': 'channelName',
        'use_old_api': 'useOldApi',
        'title': 'title',
        'id': 'id',
        'email': 'email',
        'first_name': 'firstName',
        'last_name': 'lastName'
    }
    if hasattr(NotificationTargetConfig, "attribute_map"):
        attribute_map.update(NotificationTargetConfig.attribute_map)

    def __init__(self, webhook_url=None, channel_name=None, use_old_api=None, title=None, id=None, email=None, first_name=None, last_name=None, *args, **kwargs):  # noqa: E501
        """MicrosoftTeamsNotificationTargetConfig - a model defined in Swagger"""  # noqa: E501
        self._webhook_url = None
        self._channel_name = None
        self._use_old_api = None
        self._title = None
        self._id = None
        self._email = None
        self._first_name = None
        self._last_name = None
        self.discriminator = None
        self.webhook_url = webhook_url
        self.channel_name = channel_name
        if use_old_api is not None:
            self.use_old_api = use_old_api
        if title is not None:
            self.title = title
        if id is not None:
            self.id = id
        if email is not None:
            self.email = email
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        NotificationTargetConfig.__init__(self, *args, **kwargs)

    @property
    def webhook_url(self):
        """Gets the webhook_url of this MicrosoftTeamsNotificationTargetConfig.  # noqa: E501


        :return: The webhook_url of this MicrosoftTeamsNotificationTargetConfig.  # noqa: E501
        :rtype: str
        """
        return self._webhook_url

    @webhook_url.setter
    def webhook_url(self, webhook_url):
        """Sets the webhook_url of this MicrosoftTeamsNotificationTargetConfig.


        :param webhook_url: The webhook_url of this MicrosoftTeamsNotificationTargetConfig.  # noqa: E501
        :type: str
        """
        if webhook_url is None:
            raise ValueError("Invalid value for `webhook_url`, must not be `None`")  # noqa: E501

        self._webhook_url = webhook_url

    @property
    def channel_name(self):
        """Gets the channel_name of this MicrosoftTeamsNotificationTargetConfig.  # noqa: E501


        :return: The channel_name of this MicrosoftTeamsNotificationTargetConfig.  # noqa: E501
        :rtype: str
        """
        return self._channel_name

    @channel_name.setter
    def channel_name(self, channel_name):
        """Sets the channel_name of this MicrosoftTeamsNotificationTargetConfig.


        :param channel_name: The channel_name of this MicrosoftTeamsNotificationTargetConfig.  # noqa: E501
        :type: str
        """
        if channel_name is None:
            raise ValueError("Invalid value for `channel_name`, must not be `None`")  # noqa: E501

        self._channel_name = channel_name

    @property
    def use_old_api(self):
        """Gets the use_old_api of this MicrosoftTeamsNotificationTargetConfig.  # noqa: E501


        :return: The use_old_api of this MicrosoftTeamsNotificationTargetConfig.  # noqa: E501
        :rtype: bool
        """
        return self._use_old_api

    @use_old_api.setter
    def use_old_api(self, use_old_api):
        """Sets the use_old_api of this MicrosoftTeamsNotificationTargetConfig.


        :param use_old_api: The use_old_api of this MicrosoftTeamsNotificationTargetConfig.  # noqa: E501
        :type: bool
        """

        self._use_old_api = use_old_api

    @property
    def title(self):
        """Gets the title of this MicrosoftTeamsNotificationTargetConfig.  # noqa: E501


        :return: The title of this MicrosoftTeamsNotificationTargetConfig.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this MicrosoftTeamsNotificationTargetConfig.


        :param title: The title of this MicrosoftTeamsNotificationTargetConfig.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def id(self):
        """Gets the id of this MicrosoftTeamsNotificationTargetConfig.  # noqa: E501


        :return: The id of this MicrosoftTeamsNotificationTargetConfig.  # noqa: E501
        :rtype: object
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MicrosoftTeamsNotificationTargetConfig.


        :param id: The id of this MicrosoftTeamsNotificationTargetConfig.  # noqa: E501
        :type: object
        """

        self._id = id

    @property
    def email(self):
        """Gets the email of this MicrosoftTeamsNotificationTargetConfig.  # noqa: E501


        :return: The email of this MicrosoftTeamsNotificationTargetConfig.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this MicrosoftTeamsNotificationTargetConfig.


        :param email: The email of this MicrosoftTeamsNotificationTargetConfig.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def first_name(self):
        """Gets the first_name of this MicrosoftTeamsNotificationTargetConfig.  # noqa: E501


        :return: The first_name of this MicrosoftTeamsNotificationTargetConfig.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this MicrosoftTeamsNotificationTargetConfig.


        :param first_name: The first_name of this MicrosoftTeamsNotificationTargetConfig.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this MicrosoftTeamsNotificationTargetConfig.  # noqa: E501


        :return: The last_name of this MicrosoftTeamsNotificationTargetConfig.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this MicrosoftTeamsNotificationTargetConfig.


        :param last_name: The last_name of this MicrosoftTeamsNotificationTargetConfig.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MicrosoftTeamsNotificationTargetConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MicrosoftTeamsNotificationTargetConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class JwtSettings(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'token_expiration_time': 'int',
        'refresh_token_exp_time': 'int',
        'token_issuer': 'str',
        'token_signing_key': 'str'
    }

    attribute_map = {
        'token_expiration_time': 'tokenExpirationTime',
        'refresh_token_exp_time': 'refreshTokenExpTime',
        'token_issuer': 'tokenIssuer',
        'token_signing_key': 'tokenSigningKey'
    }

    def __init__(self, token_expiration_time=None, refresh_token_exp_time=None, token_issuer=None, token_signing_key=None):  # noqa: E501
        """JwtSettings - a model defined in Swagger"""  # noqa: E501
        self._token_expiration_time = None
        self._refresh_token_exp_time = None
        self._token_issuer = None
        self._token_signing_key = None
        self.discriminator = None
        if token_expiration_time is not None:
            self.token_expiration_time = token_expiration_time
        if refresh_token_exp_time is not None:
            self.refresh_token_exp_time = refresh_token_exp_time
        if token_issuer is not None:
            self.token_issuer = token_issuer
        if token_signing_key is not None:
            self.token_signing_key = token_signing_key

    @property
    def token_expiration_time(self):
        """Gets the token_expiration_time of this JwtSettings.  # noqa: E501

        The JWT will expire after seconds.  # noqa: E501

        :return: The token_expiration_time of this JwtSettings.  # noqa: E501
        :rtype: int
        """
        return self._token_expiration_time

    @token_expiration_time.setter
    def token_expiration_time(self, token_expiration_time):
        """Sets the token_expiration_time of this JwtSettings.

        The JWT will expire after seconds.  # noqa: E501

        :param token_expiration_time: The token_expiration_time of this JwtSettings.  # noqa: E501
        :type: int
        """

        self._token_expiration_time = token_expiration_time

    @property
    def refresh_token_exp_time(self):
        """Gets the refresh_token_exp_time of this JwtSettings.  # noqa: E501

        The JWT can be refreshed during seconds.  # noqa: E501

        :return: The refresh_token_exp_time of this JwtSettings.  # noqa: E501
        :rtype: int
        """
        return self._refresh_token_exp_time

    @refresh_token_exp_time.setter
    def refresh_token_exp_time(self, refresh_token_exp_time):
        """Sets the refresh_token_exp_time of this JwtSettings.

        The JWT can be refreshed during seconds.  # noqa: E501

        :param refresh_token_exp_time: The refresh_token_exp_time of this JwtSettings.  # noqa: E501
        :type: int
        """

        self._refresh_token_exp_time = refresh_token_exp_time

    @property
    def token_issuer(self):
        """Gets the token_issuer of this JwtSettings.  # noqa: E501

        The JWT issuer.  # noqa: E501

        :return: The token_issuer of this JwtSettings.  # noqa: E501
        :rtype: str
        """
        return self._token_issuer

    @token_issuer.setter
    def token_issuer(self, token_issuer):
        """Sets the token_issuer of this JwtSettings.

        The JWT issuer.  # noqa: E501

        :param token_issuer: The token_issuer of this JwtSettings.  # noqa: E501
        :type: str
        """

        self._token_issuer = token_issuer

    @property
    def token_signing_key(self):
        """Gets the token_signing_key of this JwtSettings.  # noqa: E501

        The JWT key is used to sing token. Base64 encoded.  # noqa: E501

        :return: The token_signing_key of this JwtSettings.  # noqa: E501
        :rtype: str
        """
        return self._token_signing_key

    @token_signing_key.setter
    def token_signing_key(self, token_signing_key):
        """Sets the token_signing_key of this JwtSettings.

        The JWT key is used to sing token. Base64 encoded.  # noqa: E501

        :param token_signing_key: The token_signing_key of this JwtSettings.  # noqa: E501
        :type: str
        """

        self._token_signing_key = token_signing_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JwtSettings, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JwtSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six
from tb_rest_client.models.models_pe.entity_filter import EntityFilter  # noqa: F401,E501

class AssetSearchQueryFilter(EntityFilter):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'root_entity': 'EntityId',
        'relation_type': 'str',
        'direction': 'str',
        'max_level': 'int',
        'fetch_last_level_only': 'bool',
        'asset_types': 'list[str]'
    }
    if hasattr(EntityFilter, "swagger_types"):
        swagger_types.update(EntityFilter.swagger_types)

    attribute_map = {
        'root_entity': 'rootEntity',
        'relation_type': 'relationType',
        'direction': 'direction',
        'max_level': 'maxLevel',
        'fetch_last_level_only': 'fetchLastLevelOnly',
        'asset_types': 'assetTypes'
    }
    if hasattr(EntityFilter, "attribute_map"):
        attribute_map.update(EntityFilter.attribute_map)

    def __init__(self, root_entity=None, relation_type=None, direction=None, max_level=None, fetch_last_level_only=None, asset_types=None, *args, **kwargs):  # noqa: E501
        """AssetSearchQueryFilter - a model defined in Swagger"""  # noqa: E501
        self._root_entity = None
        self._relation_type = None
        self._direction = None
        self._max_level = None
        self._fetch_last_level_only = None
        self._asset_types = None
        self.discriminator = None
        if root_entity is not None:
            self.root_entity = root_entity
        if relation_type is not None:
            self.relation_type = relation_type
        if direction is not None:
            self.direction = direction
        if max_level is not None:
            self.max_level = max_level
        if fetch_last_level_only is not None:
            self.fetch_last_level_only = fetch_last_level_only
        if asset_types is not None:
            self.asset_types = asset_types
        EntityFilter.__init__(self, *args, **kwargs)

    @property
    def root_entity(self):
        """Gets the root_entity of this AssetSearchQueryFilter.  # noqa: E501


        :return: The root_entity of this AssetSearchQueryFilter.  # noqa: E501
        :rtype: EntityId
        """
        return self._root_entity

    @root_entity.setter
    def root_entity(self, root_entity):
        """Sets the root_entity of this AssetSearchQueryFilter.


        :param root_entity: The root_entity of this AssetSearchQueryFilter.  # noqa: E501
        :type: EntityId
        """

        self._root_entity = root_entity

    @property
    def relation_type(self):
        """Gets the relation_type of this AssetSearchQueryFilter.  # noqa: E501


        :return: The relation_type of this AssetSearchQueryFilter.  # noqa: E501
        :rtype: str
        """
        return self._relation_type

    @relation_type.setter
    def relation_type(self, relation_type):
        """Sets the relation_type of this AssetSearchQueryFilter.


        :param relation_type: The relation_type of this AssetSearchQueryFilter.  # noqa: E501
        :type: str
        """

        self._relation_type = relation_type

    @property
    def direction(self):
        """Gets the direction of this AssetSearchQueryFilter.  # noqa: E501


        :return: The direction of this AssetSearchQueryFilter.  # noqa: E501
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """Sets the direction of this AssetSearchQueryFilter.


        :param direction: The direction of this AssetSearchQueryFilter.  # noqa: E501
        :type: str
        """
        allowed_values = ["FROM", "TO"]  # noqa: E501
        if direction not in allowed_values:
            raise ValueError(
                "Invalid value for `direction` ({0}), must be one of {1}"  # noqa: E501
                .format(direction, allowed_values)
            )

        self._direction = direction

    @property
    def max_level(self):
        """Gets the max_level of this AssetSearchQueryFilter.  # noqa: E501


        :return: The max_level of this AssetSearchQueryFilter.  # noqa: E501
        :rtype: int
        """
        return self._max_level

    @max_level.setter
    def max_level(self, max_level):
        """Sets the max_level of this AssetSearchQueryFilter.


        :param max_level: The max_level of this AssetSearchQueryFilter.  # noqa: E501
        :type: int
        """

        self._max_level = max_level

    @property
    def fetch_last_level_only(self):
        """Gets the fetch_last_level_only of this AssetSearchQueryFilter.  # noqa: E501


        :return: The fetch_last_level_only of this AssetSearchQueryFilter.  # noqa: E501
        :rtype: bool
        """
        return self._fetch_last_level_only

    @fetch_last_level_only.setter
    def fetch_last_level_only(self, fetch_last_level_only):
        """Sets the fetch_last_level_only of this AssetSearchQueryFilter.


        :param fetch_last_level_only: The fetch_last_level_only of this AssetSearchQueryFilter.  # noqa: E501
        :type: bool
        """

        self._fetch_last_level_only = fetch_last_level_only

    @property
    def asset_types(self):
        """Gets the asset_types of this AssetSearchQueryFilter.  # noqa: E501


        :return: The asset_types of this AssetSearchQueryFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._asset_types

    @asset_types.setter
    def asset_types(self, asset_types):
        """Sets the asset_types of this AssetSearchQueryFilter.


        :param asset_types: The asset_types of this AssetSearchQueryFilter.  # noqa: E501
        :type: list[str]
        """

        self._asset_types = asset_types

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AssetSearchQueryFilter, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssetSearchQueryFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class DebugSettings(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'failures_enabled': 'object',
        'all_enabled': 'object',
        'all_enabled_until': 'object'
    }

    attribute_map = {
        'failures_enabled': 'failuresEnabled',
        'all_enabled': 'allEnabled',
        'all_enabled_until': 'allEnabledUntil'
    }

    def __init__(self, failures_enabled=None, all_enabled=None, all_enabled_until=None):  # noqa: E501
        """DebugSettings - a model defined in Swagger"""  # noqa: E501
        self._failures_enabled = None
        self._all_enabled = None
        self._all_enabled_until = None
        self.discriminator = None
        if failures_enabled is not None:
            self.failures_enabled = failures_enabled
        if all_enabled is not None:
            self.all_enabled = all_enabled
        if all_enabled_until is not None:
            self.all_enabled_until = all_enabled_until

    @property
    def failures_enabled(self):
        """Gets the failures_enabled of this DebugSettings.  # noqa: E501

        Debug failures.   # noqa: E501

        :return: The failures_enabled of this DebugSettings.  # noqa: E501
        :rtype: object
        """
        return self._failures_enabled

    @failures_enabled.setter
    def failures_enabled(self, failures_enabled):
        """Sets the failures_enabled of this DebugSettings.

        Debug failures.   # noqa: E501

        :param failures_enabled: The failures_enabled of this DebugSettings.  # noqa: E501
        :type: object
        """

        self._failures_enabled = failures_enabled

    @property
    def all_enabled(self):
        """Gets the all_enabled of this DebugSettings.  # noqa: E501

        Debug All. Used as a trigger for updating debugAllUntil.  # noqa: E501

        :return: The all_enabled of this DebugSettings.  # noqa: E501
        :rtype: object
        """
        return self._all_enabled

    @all_enabled.setter
    def all_enabled(self, all_enabled):
        """Sets the all_enabled of this DebugSettings.

        Debug All. Used as a trigger for updating debugAllUntil.  # noqa: E501

        :param all_enabled: The all_enabled of this DebugSettings.  # noqa: E501
        :type: object
        """

        self._all_enabled = all_enabled

    @property
    def all_enabled_until(self):
        """Gets the all_enabled_until of this DebugSettings.  # noqa: E501

        Timestamp of the end time for the processing debug events.  # noqa: E501

        :return: The all_enabled_until of this DebugSettings.  # noqa: E501
        :rtype: object
        """
        return self._all_enabled_until

    @all_enabled_until.setter
    def all_enabled_until(self, all_enabled_until):
        """Sets the all_enabled_until of this DebugSettings.

        Timestamp of the end time for the processing debug events.  # noqa: E501

        :param all_enabled_until: The all_enabled_until of this DebugSettings.  # noqa: E501
        :type: object
        """

        self._all_enabled_until = all_enabled_until

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DebugSettings, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DebugSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class MobileApp(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'MobileAppId',
        'created_time': 'int',
        'tenant_id': 'TenantId',
        'pkg_name': 'str',
        'app_secret': 'str',
        'oauth2_enabled': 'bool',
        'name': 'str'
    }

    attribute_map = {
        'id': 'id',
        'created_time': 'createdTime',
        'tenant_id': 'tenantId',
        'pkg_name': 'pkgName',
        'app_secret': 'appSecret',
        'oauth2_enabled': 'oauth2Enabled',
        'name': 'name'
    }

    def __init__(self, id=None, created_time=None, tenant_id=None, pkg_name=None, app_secret=None, oauth2_enabled=None, name=None):  # noqa: E501
        """MobileApp - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._created_time = None
        self._tenant_id = None
        self._pkg_name = None
        self._app_secret = None
        self._oauth2_enabled = None
        self._name = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if created_time is not None:
            self.created_time = created_time
        if tenant_id is not None:
            self.tenant_id = tenant_id
        self.pkg_name = pkg_name
        self.app_secret = app_secret
        if oauth2_enabled is not None:
            self.oauth2_enabled = oauth2_enabled
        if name is not None:
            self.name = name

    @property
    def id(self):
        """Gets the id of this MobileApp.  # noqa: E501


        :return: The id of this MobileApp.  # noqa: E501
        :rtype: MobileAppId
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MobileApp.


        :param id: The id of this MobileApp.  # noqa: E501
        :type: MobileAppId
        """

        self._id = id

    @property
    def created_time(self):
        """Gets the created_time of this MobileApp.  # noqa: E501


        :return: The created_time of this MobileApp.  # noqa: E501
        :rtype: int
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this MobileApp.


        :param created_time: The created_time of this MobileApp.  # noqa: E501
        :type: int
        """

        self._created_time = created_time

    @property
    def tenant_id(self):
        """Gets the tenant_id of this MobileApp.  # noqa: E501


        :return: The tenant_id of this MobileApp.  # noqa: E501
        :rtype: TenantId
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this MobileApp.


        :param tenant_id: The tenant_id of this MobileApp.  # noqa: E501
        :type: TenantId
        """

        self._tenant_id = tenant_id

    @property
    def pkg_name(self):
        """Gets the pkg_name of this MobileApp.  # noqa: E501

        Application package name. Cannot be empty  # noqa: E501

        :return: The pkg_name of this MobileApp.  # noqa: E501
        :rtype: str
        """
        return self._pkg_name

    @pkg_name.setter
    def pkg_name(self, pkg_name):
        """Sets the pkg_name of this MobileApp.

        Application package name. Cannot be empty  # noqa: E501

        :param pkg_name: The pkg_name of this MobileApp.  # noqa: E501
        :type: str
        """
        if pkg_name is None:
            raise ValueError("Invalid value for `pkg_name`, must not be `None`")  # noqa: E501

        self._pkg_name = pkg_name

    @property
    def app_secret(self):
        """Gets the app_secret of this MobileApp.  # noqa: E501

        Application secret. The length must be at least 16 characters  # noqa: E501

        :return: The app_secret of this MobileApp.  # noqa: E501
        :rtype: str
        """
        return self._app_secret

    @app_secret.setter
    def app_secret(self, app_secret):
        """Sets the app_secret of this MobileApp.

        Application secret. The length must be at least 16 characters  # noqa: E501

        :param app_secret: The app_secret of this MobileApp.  # noqa: E501
        :type: str
        """
        if app_secret is None:
            raise ValueError("Invalid value for `app_secret`, must not be `None`")  # noqa: E501

        self._app_secret = app_secret

    @property
    def oauth2_enabled(self):
        """Gets the oauth2_enabled of this MobileApp.  # noqa: E501

        Whether OAuth2 settings are enabled or not  # noqa: E501

        :return: The oauth2_enabled of this MobileApp.  # noqa: E501
        :rtype: bool
        """
        return self._oauth2_enabled

    @oauth2_enabled.setter
    def oauth2_enabled(self, oauth2_enabled):
        """Sets the oauth2_enabled of this MobileApp.

        Whether OAuth2 settings are enabled or not  # noqa: E501

        :param oauth2_enabled: The oauth2_enabled of this MobileApp.  # noqa: E501
        :type: bool
        """

        self._oauth2_enabled = oauth2_enabled

    @property
    def name(self):
        """Gets the name of this MobileApp.  # noqa: E501

        Mobile app package name  # noqa: E501

        :return: The name of this MobileApp.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this MobileApp.

        Mobile app package name  # noqa: E501

        :param name: The name of this MobileApp.  # noqa: E501
        :type: str
        """

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MobileApp, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MobileApp):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class DeviceProfileInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'EntityId',
        'tenant_id': 'TenantId',
        'name': 'str',
        'image': 'str',
        'default_dashboard_id': 'DashboardId',
        'type': 'str',
        'transport_type': 'str'
    }

    attribute_map = {
        'id': 'id',
        'tenant_id': 'tenantId',
        'name': 'name',
        'image': 'image',
        'default_dashboard_id': 'defaultDashboardId',
        'type': 'type',
        'transport_type': 'transportType'
    }

    def __init__(self, id=None, tenant_id=None, name=None, image=None, default_dashboard_id=None, type=None, transport_type=None):  # noqa: E501
        """DeviceProfileInfo - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._tenant_id = None
        self._name = None
        self._image = None
        self._default_dashboard_id = None
        self._type = None
        self._transport_type = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if name is not None:
            self.name = name
        if image is not None:
            self.image = image
        if default_dashboard_id is not None:
            self.default_dashboard_id = default_dashboard_id
        if type is not None:
            self.type = type
        if transport_type is not None:
            self.transport_type = transport_type

    @property
    def id(self):
        """Gets the id of this DeviceProfileInfo.  # noqa: E501


        :return: The id of this DeviceProfileInfo.  # noqa: E501
        :rtype: EntityId
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DeviceProfileInfo.


        :param id: The id of this DeviceProfileInfo.  # noqa: E501
        :type: EntityId
        """

        self._id = id

    @property
    def tenant_id(self):
        """Gets the tenant_id of this DeviceProfileInfo.  # noqa: E501


        :return: The tenant_id of this DeviceProfileInfo.  # noqa: E501
        :rtype: TenantId
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this DeviceProfileInfo.


        :param tenant_id: The tenant_id of this DeviceProfileInfo.  # noqa: E501
        :type: TenantId
        """

        self._tenant_id = tenant_id

    @property
    def name(self):
        """Gets the name of this DeviceProfileInfo.  # noqa: E501

        Entity Name  # noqa: E501

        :return: The name of this DeviceProfileInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DeviceProfileInfo.

        Entity Name  # noqa: E501

        :param name: The name of this DeviceProfileInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def image(self):
        """Gets the image of this DeviceProfileInfo.  # noqa: E501

        Either URL or Base64 data of the icon. Used in the mobile application to visualize set of device profiles in the grid view.   # noqa: E501

        :return: The image of this DeviceProfileInfo.  # noqa: E501
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this DeviceProfileInfo.

        Either URL or Base64 data of the icon. Used in the mobile application to visualize set of device profiles in the grid view.   # noqa: E501

        :param image: The image of this DeviceProfileInfo.  # noqa: E501
        :type: str
        """

        self._image = image

    @property
    def default_dashboard_id(self):
        """Gets the default_dashboard_id of this DeviceProfileInfo.  # noqa: E501


        :return: The default_dashboard_id of this DeviceProfileInfo.  # noqa: E501
        :rtype: DashboardId
        """
        return self._default_dashboard_id

    @default_dashboard_id.setter
    def default_dashboard_id(self, default_dashboard_id):
        """Sets the default_dashboard_id of this DeviceProfileInfo.


        :param default_dashboard_id: The default_dashboard_id of this DeviceProfileInfo.  # noqa: E501
        :type: DashboardId
        """

        self._default_dashboard_id = default_dashboard_id

    @property
    def type(self):
        """Gets the type of this DeviceProfileInfo.  # noqa: E501

        Type of the profile. Always 'DEFAULT' for now. Reserved for future use.  # noqa: E501

        :return: The type of this DeviceProfileInfo.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this DeviceProfileInfo.

        Type of the profile. Always 'DEFAULT' for now. Reserved for future use.  # noqa: E501

        :param type: The type of this DeviceProfileInfo.  # noqa: E501
        :type: str
        """
        allowed_values = ["DEFAULT"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def transport_type(self):
        """Gets the transport_type of this DeviceProfileInfo.  # noqa: E501

        Type of the transport used to connect the device. Default transport supports HTTP, CoAP and MQTT.  # noqa: E501

        :return: The transport_type of this DeviceProfileInfo.  # noqa: E501
        :rtype: str
        """
        return self._transport_type

    @transport_type.setter
    def transport_type(self, transport_type):
        """Sets the transport_type of this DeviceProfileInfo.

        Type of the transport used to connect the device. Default transport supports HTTP, CoAP and MQTT.  # noqa: E501

        :param transport_type: The transport_type of this DeviceProfileInfo.  # noqa: E501
        :type: str
        """
        allowed_values = ["DEFAULT", "MQTT", "COAP", "LWM2M", "SNMP"]  # noqa: E501
        if transport_type not in allowed_values:
            raise ValueError(
                "Invalid value for `transport_type` ({0}), must be one of {1}"  # noqa: E501
                .format(transport_type, allowed_values)
            )

        self._transport_type = transport_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DeviceProfileInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeviceProfileInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six
from tb_rest_client.models.models_ce.delivery_method_notification_template import DeliveryMethodNotificationTemplate  # noqa: F401,E501

class EmailDeliveryMethodNotificationTemplate(DeliveryMethodNotificationTemplate):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'subject': 'str'
    }
    if hasattr(DeliveryMethodNotificationTemplate, "swagger_types"):
        swagger_types.update(DeliveryMethodNotificationTemplate.swagger_types)

    attribute_map = {
        'subject': 'subject'
    }
    if hasattr(DeliveryMethodNotificationTemplate, "attribute_map"):
        attribute_map.update(DeliveryMethodNotificationTemplate.attribute_map)

    def __init__(self, subject=None, *args, **kwargs):  # noqa: E501
        """EmailDeliveryMethodNotificationTemplate - a model defined in Swagger"""  # noqa: E501
        self._subject = None
        self.discriminator = None
        self.subject = subject
        DeliveryMethodNotificationTemplate.__init__(self, *args, **kwargs)

    @property
    def subject(self):
        """Gets the subject of this EmailDeliveryMethodNotificationTemplate.  # noqa: E501


        :return: The subject of this EmailDeliveryMethodNotificationTemplate.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this EmailDeliveryMethodNotificationTemplate.


        :param subject: The subject of this EmailDeliveryMethodNotificationTemplate.  # noqa: E501
        :type: str
        """
        if subject is None:
            raise ValueError("Invalid value for `subject`, must not be `None`")  # noqa: E501

        self._subject = subject

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EmailDeliveryMethodNotificationTemplate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailDeliveryMethodNotificationTemplate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class AlarmConditionFilterKey(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'key': 'str'
    }

    attribute_map = {
        'type': 'type',
        'key': 'key'
    }

    def __init__(self, type=None, key=None):  # noqa: E501
        """AlarmConditionFilterKey - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._key = None
        self.discriminator = None
        if type is not None:
            self.type = type
        if key is not None:
            self.key = key

    @property
    def type(self):
        """Gets the type of this AlarmConditionFilterKey.  # noqa: E501

        The key type  # noqa: E501

        :return: The type of this AlarmConditionFilterKey.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this AlarmConditionFilterKey.

        The key type  # noqa: E501

        :param type: The type of this AlarmConditionFilterKey.  # noqa: E501
        :type: str
        """
        allowed_values = ["ATTRIBUTE", "TIME_SERIES", "ENTITY_FIELD", "CONSTANT"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def key(self):
        """Gets the key of this AlarmConditionFilterKey.  # noqa: E501

        String value representing the key  # noqa: E501

        :return: The key of this AlarmConditionFilterKey.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this AlarmConditionFilterKey.

        String value representing the key  # noqa: E501

        :param key: The key of this AlarmConditionFilterKey.  # noqa: E501
        :type: str
        """

        self._key = key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AlarmConditionFilterKey, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AlarmConditionFilterKey):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six
from tb_rest_client.models.models_pe.transport_payload_type_configuration import TransportPayloadTypeConfiguration  # noqa: F401,E501

class ProtoTransportPayloadConfiguration(TransportPayloadTypeConfiguration):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'device_telemetry_proto_schema': 'str',
        'device_attributes_proto_schema': 'str',
        'device_rpc_request_proto_schema': 'str',
        'device_rpc_response_proto_schema': 'str',
        'enable_compatibility_with_json_payload_format': 'bool',
        'use_json_payload_format_for_default_downlink_topics': 'bool'
    }
    if hasattr(TransportPayloadTypeConfiguration, "swagger_types"):
        swagger_types.update(TransportPayloadTypeConfiguration.swagger_types)

    attribute_map = {
        'device_telemetry_proto_schema': 'deviceTelemetryProtoSchema',
        'device_attributes_proto_schema': 'deviceAttributesProtoSchema',
        'device_rpc_request_proto_schema': 'deviceRpcRequestProtoSchema',
        'device_rpc_response_proto_schema': 'deviceRpcResponseProtoSchema',
        'enable_compatibility_with_json_payload_format': 'enableCompatibilityWithJsonPayloadFormat',
        'use_json_payload_format_for_default_downlink_topics': 'useJsonPayloadFormatForDefaultDownlinkTopics'
    }
    if hasattr(TransportPayloadTypeConfiguration, "attribute_map"):
        attribute_map.update(TransportPayloadTypeConfiguration.attribute_map)

    def __init__(self, device_telemetry_proto_schema=None, device_attributes_proto_schema=None, device_rpc_request_proto_schema=None, device_rpc_response_proto_schema=None, enable_compatibility_with_json_payload_format=None, use_json_payload_format_for_default_downlink_topics=None, *args, **kwargs):  # noqa: E501
        """ProtoTransportPayloadConfiguration - a model defined in Swagger"""  # noqa: E501
        self._device_telemetry_proto_schema = None
        self._device_attributes_proto_schema = None
        self._device_rpc_request_proto_schema = None
        self._device_rpc_response_proto_schema = None
        self._enable_compatibility_with_json_payload_format = None
        self._use_json_payload_format_for_default_downlink_topics = None
        self.discriminator = None
        if device_telemetry_proto_schema is not None:
            self.device_telemetry_proto_schema = device_telemetry_proto_schema
        if device_attributes_proto_schema is not None:
            self.device_attributes_proto_schema = device_attributes_proto_schema
        if device_rpc_request_proto_schema is not None:
            self.device_rpc_request_proto_schema = device_rpc_request_proto_schema
        if device_rpc_response_proto_schema is not None:
            self.device_rpc_response_proto_schema = device_rpc_response_proto_schema
        if enable_compatibility_with_json_payload_format is not None:
            self.enable_compatibility_with_json_payload_format = enable_compatibility_with_json_payload_format
        if use_json_payload_format_for_default_downlink_topics is not None:
            self.use_json_payload_format_for_default_downlink_topics = use_json_payload_format_for_default_downlink_topics
        TransportPayloadTypeConfiguration.__init__(self, *args, **kwargs)

    @property
    def device_telemetry_proto_schema(self):
        """Gets the device_telemetry_proto_schema of this ProtoTransportPayloadConfiguration.  # noqa: E501


        :return: The device_telemetry_proto_schema of this ProtoTransportPayloadConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._device_telemetry_proto_schema

    @device_telemetry_proto_schema.setter
    def device_telemetry_proto_schema(self, device_telemetry_proto_schema):
        """Sets the device_telemetry_proto_schema of this ProtoTransportPayloadConfiguration.


        :param device_telemetry_proto_schema: The device_telemetry_proto_schema of this ProtoTransportPayloadConfiguration.  # noqa: E501
        :type: str
        """

        self._device_telemetry_proto_schema = device_telemetry_proto_schema

    @property
    def device_attributes_proto_schema(self):
        """Gets the device_attributes_proto_schema of this ProtoTransportPayloadConfiguration.  # noqa: E501


        :return: The device_attributes_proto_schema of this ProtoTransportPayloadConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._device_attributes_proto_schema

    @device_attributes_proto_schema.setter
    def device_attributes_proto_schema(self, device_attributes_proto_schema):
        """Sets the device_attributes_proto_schema of this ProtoTransportPayloadConfiguration.


        :param device_attributes_proto_schema: The device_attributes_proto_schema of this ProtoTransportPayloadConfiguration.  # noqa: E501
        :type: str
        """

        self._device_attributes_proto_schema = device_attributes_proto_schema

    @property
    def device_rpc_request_proto_schema(self):
        """Gets the device_rpc_request_proto_schema of this ProtoTransportPayloadConfiguration.  # noqa: E501


        :return: The device_rpc_request_proto_schema of this ProtoTransportPayloadConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._device_rpc_request_proto_schema

    @device_rpc_request_proto_schema.setter
    def device_rpc_request_proto_schema(self, device_rpc_request_proto_schema):
        """Sets the device_rpc_request_proto_schema of this ProtoTransportPayloadConfiguration.


        :param device_rpc_request_proto_schema: The device_rpc_request_proto_schema of this ProtoTransportPayloadConfiguration.  # noqa: E501
        :type: str
        """

        self._device_rpc_request_proto_schema = device_rpc_request_proto_schema

    @property
    def device_rpc_response_proto_schema(self):
        """Gets the device_rpc_response_proto_schema of this ProtoTransportPayloadConfiguration.  # noqa: E501


        :return: The device_rpc_response_proto_schema of this ProtoTransportPayloadConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._device_rpc_response_proto_schema

    @device_rpc_response_proto_schema.setter
    def device_rpc_response_proto_schema(self, device_rpc_response_proto_schema):
        """Sets the device_rpc_response_proto_schema of this ProtoTransportPayloadConfiguration.


        :param device_rpc_response_proto_schema: The device_rpc_response_proto_schema of this ProtoTransportPayloadConfiguration.  # noqa: E501
        :type: str
        """

        self._device_rpc_response_proto_schema = device_rpc_response_proto_schema

    @property
    def enable_compatibility_with_json_payload_format(self):
        """Gets the enable_compatibility_with_json_payload_format of this ProtoTransportPayloadConfiguration.  # noqa: E501


        :return: The enable_compatibility_with_json_payload_format of this ProtoTransportPayloadConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._enable_compatibility_with_json_payload_format

    @enable_compatibility_with_json_payload_format.setter
    def enable_compatibility_with_json_payload_format(self, enable_compatibility_with_json_payload_format):
        """Sets the enable_compatibility_with_json_payload_format of this ProtoTransportPayloadConfiguration.


        :param enable_compatibility_with_json_payload_format: The enable_compatibility_with_json_payload_format of this ProtoTransportPayloadConfiguration.  # noqa: E501
        :type: bool
        """

        self._enable_compatibility_with_json_payload_format = enable_compatibility_with_json_payload_format

    @property
    def use_json_payload_format_for_default_downlink_topics(self):
        """Gets the use_json_payload_format_for_default_downlink_topics of this ProtoTransportPayloadConfiguration.  # noqa: E501


        :return: The use_json_payload_format_for_default_downlink_topics of this ProtoTransportPayloadConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._use_json_payload_format_for_default_downlink_topics

    @use_json_payload_format_for_default_downlink_topics.setter
    def use_json_payload_format_for_default_downlink_topics(self, use_json_payload_format_for_default_downlink_topics):
        """Sets the use_json_payload_format_for_default_downlink_topics of this ProtoTransportPayloadConfiguration.


        :param use_json_payload_format_for_default_downlink_topics: The use_json_payload_format_for_default_downlink_topics of this ProtoTransportPayloadConfiguration.  # noqa: E501
        :type: bool
        """

        self._use_json_payload_format_for_default_downlink_topics = use_json_payload_format_for_default_downlink_topics

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProtoTransportPayloadConfiguration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProtoTransportPayloadConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CustomMenuDeleteResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'success': 'bool',
        'assignee_type': 'str',
        'assignee_list': 'list[EntityInfo]'
    }

    attribute_map = {
        'success': 'success',
        'assignee_type': 'assigneeType',
        'assignee_list': 'assigneeList'
    }

    def __init__(self, success=None, assignee_type=None, assignee_list=None):  # noqa: E501
        """CustomMenuDeleteResult - a model defined in Swagger"""  # noqa: E501
        self._success = None
        self._assignee_type = None
        self._assignee_list = None
        self.discriminator = None
        if success is not None:
            self.success = success
        if assignee_type is not None:
            self.assignee_type = assignee_type
        if assignee_list is not None:
            self.assignee_list = assignee_list

    @property
    def success(self):
        """Gets the success of this CustomMenuDeleteResult.  # noqa: E501


        :return: The success of this CustomMenuDeleteResult.  # noqa: E501
        :rtype: bool
        """
        return self._success

    @success.setter
    def success(self, success):
        """Sets the success of this CustomMenuDeleteResult.


        :param success: The success of this CustomMenuDeleteResult.  # noqa: E501
        :type: bool
        """

        self._success = success

    @property
    def assignee_type(self):
        """Gets the assignee_type of this CustomMenuDeleteResult.  # noqa: E501


        :return: The assignee_type of this CustomMenuDeleteResult.  # noqa: E501
        :rtype: str
        """
        return self._assignee_type

    @assignee_type.setter
    def assignee_type(self, assignee_type):
        """Sets the assignee_type of this CustomMenuDeleteResult.


        :param assignee_type: The assignee_type of this CustomMenuDeleteResult.  # noqa: E501
        :type: str
        """
        allowed_values = ["NO_ASSIGN", "ALL", "CUSTOMERS", "USERS"]  # noqa: E501
        if assignee_type not in allowed_values:
            raise ValueError(
                "Invalid value for `assignee_type` ({0}), must be one of {1}"  # noqa: E501
                .format(assignee_type, allowed_values)
            )

        self._assignee_type = assignee_type

    @property
    def assignee_list(self):
        """Gets the assignee_list of this CustomMenuDeleteResult.  # noqa: E501


        :return: The assignee_list of this CustomMenuDeleteResult.  # noqa: E501
        :rtype: list[EntityInfo]
        """
        return self._assignee_list

    @assignee_list.setter
    def assignee_list(self, assignee_list):
        """Sets the assignee_list of this CustomMenuDeleteResult.


        :param assignee_list: The assignee_list of this CustomMenuDeleteResult.  # noqa: E501
        :type: list[EntityInfo]
        """

        self._assignee_list = assignee_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CustomMenuDeleteResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustomMenuDeleteResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
